package sgc.portal.cw.cw0801.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw0801.dto.CW08010001USearch;
import sgc.portal.cw.cw0801.model.CW08010001U;
import sgc.portal.cw.cw0801.model.CW08010002U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CW08010001UMapper {
	
	//회의실등록  조회
	List<EasyHashMap<String, Object>> selectZehrRomInfoList(CW08010001USearch search);
	
	//위치등록  조회
	List<EasyHashMap<String, Object>> selectZehrRomLoctnList(CW08010001USearch search);
	
	List<EasyHashMap<String, Object>> selectZherRomDisplList();

	//회의실등록  수정삭체추가
	void insertZehrRomInfo(CW08010001U cW08010001U);
	void deleteZehrRomInfo(CW08010001U cW08010001U);
	void updateZehrRomInfo(CW08010001U cW08010001U);
	
	int selectZehrRomInfoBunhoCount(CW08010001U cW08010001U);
	int selectZehrRomInfoTelCount(CW08010001U cW08010001U);
	int selectZehrRomResrvtnCount(CW08010001U cW08010001U);
	void deleteZehrRomHistr(CW08010001U cW08010001U);
	void deleteZehrRomResrvtn(CW08010001U cW08010001U);
	void deleteZehrRomDispl(CW08010001U cW08010001U);
	int selectZehrRomInfoLocationCount(CW08010002U cW08010002U);
	void deleteZehrRomLoctnlAtchfileIdAdmin(CW08010002U cW08010002U);
	int selectAtchfileIdZehrRomLoctnCount(CW08010002U cW08010002U);
	
	//위치등록  수정삭체추가
	void insertZehrRomLoctn(CW08010002U cW08010002U);
	void deleteZehrRomLoctn(CW08010002U cW08010002U);
	void updateZehrRomLoctn(CW08010002U cW08010002U);
	
	//디스플레이  수정삭체추가
	void updateZherRomDispl1(CW08010001U cW08010001U);
	void updateZherRomDispl2(CW08010001U cW08010001U);
	void updateZherRomDisplAll(CW08010001U cW08010001U);
	
	List<EasyHashMap<String, Object>> selectZehrRomLoctnCommList();
}
